@@ -3,7 +3,6 @@ from __future__ import annotations
 import warnings
 from copy import deepcopy
 from datetime import datetime
-from html import escape
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -21,11 +20,10 @@ from typing import (
 from dateutil import tz
 
 import pystac
-from pystac import CatalogType, STACObjectType
+from pystac import CatalogType, STACError, STACObjectType
 from pystac.asset import Asset
 from pystac.catalog import Catalog
 from pystac.errors import DeprecatedWarning, ExtensionNotImplemented, STACTypeError
-from pystac.html.jinja_env import get_jinja_env
 from pystac.layout import HrefLayoutStrategy
 from pystac.link import Link
 from pystac.provider import Provider
@@ -35,7 +33,13 @@ from pystac.serialization import (
     migrate_to_latest,
 )
 from pystac.summaries import Summaries
-from pystac.utils import datetime_to_str, str_to_datetime
+from pystac.utils import (
+    datetime_to_str,
+    is_absolute_href,
+    make_absolute_href,
+    make_relative_href,
+    str_to_datetime,
+)
 
 if TYPE_CHECKING:
     from pystac.item import Item
@@ -86,10 +90,10 @@ class SpatialExtent:
         self.extra_fields = extra_fields or {}
 
     def to_dict(self) -> Dict[str, Any]:
-        """Generate a dictionary representing the JSON of this SpatialExtent.
+        """Returns this spatial extent as a dictionary.
 
         Returns:
-            dict: A serialization of the SpatialExtent that can be written out as JSON.
+            dict: A serialization of the SpatialExtent.
         """
         d = {"bbox": self.bboxes, **self.extra_fields}
         return d
@@ -212,10 +216,10 @@ class TemporalExtent:
         self.extra_fields = extra_fields or {}
 
     def to_dict(self) -> Dict[str, Any]:
-        """Generate a dictionary representing the JSON of this TemporalExtent.
+        """Returns this temporal extent as a dictionary.
 
         Returns:
-            dict: A serialization of the TemporalExtent that can be written out as JSON.
+            dict: A serialization of the TemporalExtent.
         """
         encoded_intervals: List[List[Optional[str]]] = []
         for i in self.intervals:
@@ -311,10 +315,10 @@ class Extent:
         self.extra_fields = extra_fields or {}
 
     def to_dict(self) -> Dict[str, Any]:
-        """Generate a dictionary representing the JSON of this Extent.
+        """Returns this extent as a dictionary.
 
         Returns:
-            dict: A serialization of the Extent that can be written out as JSON.
+            dict: A serialization of the Extent.
         """
         d = {
             "spatial": self.spatial.to_dict(),
@@ -540,22 +544,16 @@ class Collection(Catalog):
     def __repr__(self) -> str:
         return "<Collection id={}>".format(self.id)
 
-    def _repr_html_(self) -> str:
-        jinja_env = get_jinja_env()
-        if jinja_env:
-            template = jinja_env.get_template("Collection.jinja2")
-            return str(template.render(catalog=self))
-        else:
-            return escape(repr(self))
-
     def add_item(
         self,
         item: Item,
         title: Optional[str] = None,
         strategy: Optional[HrefLayoutStrategy] = None,
-    ) -> None:
-        super().add_item(item, title, strategy)
+        set_parent: bool = True,
+    ) -> Link:
+        link = super().add_item(item, title, strategy, set_parent)
         item.set_collection(self)
+        return link
 
     def to_dict(
         self, include_self_link: bool = True, transform_hrefs: bool = True
@@ -626,7 +624,7 @@ class Collection(Catalog):
             d = migrate_to_latest(d, info)
 
         if not cls.matches_object_type(d):
-            raise STACTypeError(f"{d} does not represent a {cls.__name__} instance")
+            raise STACTypeError(d, cls)
 
         catalog_type = CatalogType.determine_type(d)
 
@@ -694,6 +692,27 @@ class Collection(Catalog):
 
         return collection
 
+    def get_item(self, id: str, recursive: bool = False) -> Optional[Item]:
+        """Returns an item with a given ID.
+
+        Args:
+            id : The ID of the item to find.
+            recursive : If True, search this collection and all children for the
+                item; otherwise, only search the items of this collection. Defaults
+                to False.
+
+        Return:
+            Item or None: The item with the given ID, or None if not found.
+        """
+        try:
+            return next(self.get_items(id, recursive=recursive), None)
+        except TypeError as e:
+            if any("recursive" in arg for arg in e.args):
+                # For inherited classes that do not yet support recursive
+                # See https://github.com/stac-utils/pystac-client/issues/485
+                return super().get_item(id, recursive=recursive)
+            raise e
+
     def get_assets(
         self,
         media_type: Optional[Union[str, pystac.MediaType]] = None,
@@ -711,18 +730,15 @@ class Collection(Catalog):
             Dict[str, Asset]: A dictionary of assets that match ``media_type``
             and/or ``role`` if set or else all of this collection's assets.
         """
-        if media_type is None and role is None:
-            return dict(self.assets.items())
-        assets = dict()
-        for key, asset in self.assets.items():
-            if (media_type is None or asset.media_type == media_type) and (
-                role is None or asset.has_role(role)
-            ):
-                assets[key] = asset
-        return assets
+        return {
+            k: deepcopy(v)
+            for k, v in self.assets.items()
+            if (media_type is None or v.media_type == media_type)
+            and (role is None or v.has_role(role))
+        }
 
     def add_asset(self, key: str, asset: Asset) -> None:
-        """Adds an Asset to this item.
+        """Adds an Asset to this collection.
 
         Args:
             key : The unique key of this asset.
@@ -731,26 +747,72 @@ class Collection(Catalog):
         asset.set_owner(self)
         self.assets[key] = asset
 
+    def delete_asset(self, key: str) -> None:
+        """Deletes the asset at the given key, and removes the asset's data
+        file from the local filesystem.
+
+        It is an error to attempt to delete an asset's file if it is on a
+        remote filesystem.
+
+        To delete the asset without removing the file, use
+        `del collection.assets["key"]`.
+
+        Args:
+            key: The unique key of this asset.
+        """
+        asset = self.assets[key]
+        asset.set_owner(self)
+        asset.delete()
+
+        del self.assets[key]
+
+    def make_asset_hrefs_relative(self) -> Collection:
+        """Modify each asset's HREF to be relative to this collection's self HREF.
+
+        Returns:
+            Collection: self
+        """
+        self_href = self.get_self_href()
+        for asset in self.assets.values():
+            if is_absolute_href(asset.href):
+                if self_href is None:
+                    raise STACError(
+                        "Cannot make asset HREFs relative " "if no self_href is set."
+                    )
+                asset.href = make_relative_href(asset.href, self_href)
+        return self
+
+    def make_asset_hrefs_absolute(self) -> Collection:
+        """Modify each asset's HREF to be absolute.
+
+        Any asset HREFs that are relative will be modified to absolute based on this
+        collection's self HREF.
+
+        Returns:
+            Collection: self
+        """
+        self_href = self.get_self_href()
+        for asset in self.assets.values():
+            if not is_absolute_href(asset.href):
+                if self_href is None:
+                    raise STACError(
+                        "Cannot make relative asset HREFs absolute "
+                        "if no self_href is set."
+                    )
+                asset.href = make_absolute_href(asset.href, self_href)
+        return self
+
     def update_extent_from_items(self) -> None:
         """
         Update datetime and bbox based on all items to a single bbox and time window.
         """
-        self.extent = Extent.from_items(self.get_all_items())
+        self.extent = Extent.from_items(self.get_items(recursive=True))
 
     def full_copy(
         self, root: Optional["Catalog"] = None, parent: Optional["Catalog"] = None
     ) -> Collection:
         return cast(Collection, super().full_copy(root, parent))
 
-    @classmethod
-    def from_file(
-        cls: Type[C], href: str, stac_io: Optional[pystac.StacIO] = None
-    ) -> C:
-        result = super().from_file(href, stac_io)
-        if not isinstance(result, Collection):
-            raise pystac.STACTypeError(f"{result} is not a {Collection}.")
-        return result
-
     @classmethod
     def matches_object_type(cls, d: Dict[str, Any]) -> bool:
         return identify_stac_object_type(d) == STACObjectType.COLLECTION
