@@ -11,7 +11,10 @@ from pystac.serialization.identify import STACJSONDescription, STACVersionID
 from pystac.utils import StringEnum, get_required, map_opt
 
 SCHEMA_URI = "https://stac-extensions.github.io/label/v1.0.1/schema.json"
-
+SCHEMA_URIS = [
+    "https://stac-extensions.github.io/label/v1.0.0/schema.json",
+    SCHEMA_URI,
+]
 PREFIX = "label:"
 
 PROPERTIES_PROP = PREFIX + "properties"
@@ -141,7 +144,7 @@ class LabelClasses:
         return self.to_dict() == o
 
     def to_dict(self) -> Dict[str, Any]:
-        """Returns the dictionary representing the JSON of this instance."""
+        """Returns this label classes object as a dictionary."""
         return self.properties
 
 
@@ -197,7 +200,7 @@ class LabelCount:
         self.properties["count"] = v
 
     def to_dict(self) -> Dict[str, Any]:
-        """Returns the dictionary representing the JSON of this instance."""
+        """Returns this label count object as a dictionary."""
         return self.properties
 
     def __eq__(self, o: object) -> bool:
@@ -262,7 +265,7 @@ class LabelStatistics:
         self.properties["value"] = v
 
     def to_dict(self) -> Dict[str, Any]:
-        """Returns the dictionary representing the JSON of this LabelStatistics."""
+        """Returns this label statistics object as a dictionary."""
         return self.properties
 
     def __eq__(self, o: object) -> bool:
@@ -417,7 +420,7 @@ class LabelOverview:
         return LabelOverview.create(self.property_key, counts=new_counts)
 
     def to_dict(self) -> Dict[str, Any]:
-        """Returns the dictionary representing the JSON of this LabelOverview."""
+        """Returns this label overview as a dictionary."""
         return self.properties
 
     def __eq__(self, o: object) -> bool:
@@ -691,6 +694,10 @@ class LabelExtension(ExtensionManagementMixin[Union[pystac.Item, pystac.Collecti
     def get_schema_uri(cls) -> str:
         return SCHEMA_URI
 
+    @classmethod
+    def get_schema_uris(cls) -> List[str]:
+        return SCHEMA_URIS
+
     @classmethod
     def ext(cls, obj: pystac.Item, add_if_missing: bool = False) -> LabelExtension:
         """Extends the given STAC Object with properties from the :stac-ext:`Label
@@ -702,9 +709,7 @@ class LabelExtension(ExtensionManagementMixin[Union[pystac.Item, pystac.Collecti
             cls.validate_has_extension(obj, add_if_missing)
             return cls(obj)
         else:
-            raise pystac.ExtensionTypeError(
-                f"Label extension does not apply to type '{type(obj).__name__}'"
-            )
+            raise pystac.ExtensionTypeError(cls._ext_error_message(obj))
 
     @classmethod
     def summaries(
@@ -791,7 +796,7 @@ class LabelExtensionHooks(ExtensionHooks):
     schema_uri: str = SCHEMA_URI
     prev_extension_ids = {
         "label",
-        "https://stac-extensions.github.io/label/v1.0.0/schema.json",
+        *[uri for uri in SCHEMA_URIS if uri != SCHEMA_URI],
     }
     stac_object_types = {pystac.STACObjectType.ITEM}
 
