@@ -1,13 +1,16 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from html import escape
 from typing import (
     TYPE_CHECKING,
     Any,
+    Callable,
     Dict,
     Iterable,
     List,
     Optional,
+    Set,
     Type,
     TypeVar,
     Union,
@@ -16,8 +19,14 @@ from typing import (
 
 import pystac
 from pystac import STACError
+from pystac.html.jinja_env import get_jinja_env
 from pystac.link import Link
-from pystac.utils import StringEnum, is_absolute_href, make_absolute_href
+from pystac.utils import (
+    StringEnum,
+    is_absolute_href,
+    make_absolute_href,
+    make_posix_style,
+)
 
 if TYPE_CHECKING:
     from pystac.catalog import Catalog
@@ -50,6 +59,9 @@ class STACObject(ABC):
 
     STAC_OBJECT_TYPE: STACObjectType
 
+    _allow_parent_to_override_href: bool = True
+    """Private attribute for whether parent objects should override on normalization"""
+
     def __init__(self, stac_extensions: List[str]) -> None:
         self.links = []
         self.stac_extensions = stac_extensions
@@ -125,6 +137,43 @@ class STACObject(ABC):
         self.links = keep
         return remove
 
+    def target_in_hierarchy(self, target: Union[str, STACObject]) -> bool:
+        """Determine if target is somewhere in the hierarchical link tree of
+        a STACObject.
+
+        Args:
+            target: A string or STACObject to search for
+
+        Returns:
+            bool: Returns True if the target was found in the hierarchical link tree
+                for the current STACObject
+        """
+
+        def traverse(
+            obj: Union[str, STACObject], visited: Set[Union[str, STACObject]]
+        ) -> bool:
+            if obj == target:
+                return True
+            if isinstance(obj, str):
+                return False
+
+            new_targets = [
+                link.target
+                for link in obj.links
+                if link.is_hierarchical() and link.target not in visited
+            ]
+            if target in new_targets:
+                return True
+
+            for subtree in new_targets:
+                visited.add(subtree)
+                if traverse(subtree, visited):
+                    return True
+
+            return False
+
+        return traverse(self, set([self]))
+
     def get_single_link(
         self,
         rel: Optional[Union[str, pystac.RelType]] = None,
@@ -346,7 +395,10 @@ class STACObject(ABC):
             self.add_link(Link.parent(parent))
 
     def get_stac_objects(
-        self, rel: Union[str, pystac.RelType], typ: Optional[Type[STACObject]] = None
+        self,
+        rel: Union[str, pystac.RelType],
+        typ: Optional[Type[STACObject]] = None,
+        modify_links: Optional[Callable[[List[Link]], List[Link]]] = None,
     ) -> Iterable[STACObject]:
         """Gets the :class:`~pystac.STACObject` instances that are linked to
         by links with their ``rel`` property matching the passed in argument.
@@ -356,6 +408,9 @@ class STACObject(ABC):
                 ``rel`` property against.
             typ : If not ``None``, objects will only be yielded if they are instances of
                 ``typ``.
+            modify_links : A function that modifies the list of links before they are
+                iterated over. For instance, this option can be used to sort the list
+                so that links matching a particular pattern are earlier in the iterator.
 
         Returns:
             Iterable[STACObjects]: A possibly empty iterable of STACObjects that are
@@ -363,6 +418,9 @@ class STACObject(ABC):
             type ``typ`` (if given).
         """
         links = self.links[:]
+        if modify_links:
+            links = modify_links(links)
+
         for i in range(0, len(links)):
             link = links[i]
             if link.rel == rel:
@@ -505,7 +563,7 @@ class STACObject(ABC):
     def to_dict(
         self, include_self_link: bool = True, transform_hrefs: bool = True
     ) -> Dict[str, Any]:
-        """Generate a dictionary representing the JSON of this serialized object.
+        """Returns this object as a dictionary.
 
         Args:
             include_self_link : If True, the dict will contain a self link
@@ -517,10 +575,18 @@ class STACObject(ABC):
                 hierarchical link HREFs will be transformed to be relative to the
                 catalog root.
 
-            dict: A serialization of the object that can be written out as JSON.
+            dict: A serialization of the object.
         """
         raise NotImplementedError
 
+    def _repr_html_(self) -> str:
+        jinja_env = get_jinja_env()
+        if jinja_env:
+            template = jinja_env.get_template("JSON.jinja2")
+            return str(template.render(dict=self.to_dict(transform_hrefs=False)))
+        else:
+            return escape(repr(self))
+
     @abstractmethod
     def clone(self) -> STACObject:
         """Clones this object.
@@ -553,6 +619,8 @@ class STACObject(ABC):
         if cls == STACObject:
             return cast(S, pystac.read_file(href))
 
+        href = make_posix_style(href)
+
         if stac_io is None:
             stac_io = pystac.StacIO.default()
 
@@ -562,10 +630,6 @@ class STACObject(ABC):
         d = stac_io.read_json(href)
         o = cls.from_dict(d, href=href, migrate=True, preserve_dict=False)
 
-        # Set the self HREF, if it's not already set to something else.
-        if o.get_self_href() is None:
-            o.set_self_href(href)
-
         # If this is a root catalog, set the root to the catalog instance.
         root_link = o.get_root_link()
         if root_link is not None:
