@@ -4,6 +4,8 @@ import tempfile
 import unittest
 from typing import List, Union
 
+import pytest
+
 import pystac
 import pystac.validation
 from pystac import Catalog, CatalogType, Collection, ExtensionTypeError, Item
@@ -19,6 +21,7 @@ from pystac.extensions.label import (
     LabelType,
 )
 from pystac.utils import get_opt
+from tests.conftest import get_data_file
 from tests.utils import TestCases, assert_to_from_dict
 
 
@@ -102,6 +105,7 @@ class LabelTest(unittest.TestCase):
 
         assert_to_from_dict(self, Item, label_example_1_dict)
 
+    @pytest.mark.vcr()
     def test_from_file(self) -> None:
         label_example_1 = Item.from_file(self.label_example_1_uri)
 
@@ -134,7 +138,7 @@ class LabelTest(unittest.TestCase):
     def test_get_sources(self) -> None:
         cat = TestCases.case_1()
 
-        items = list(cat.get_all_items())
+        items = list(cat.get_items(recursive=True))
         item_ids = set([i.id for i in items])
 
         for li in items:
@@ -143,6 +147,7 @@ class LabelTest(unittest.TestCase):
                 self.assertEqual(len(sources), 1)
                 self.assertTrue(sources[0].id in item_ids)
 
+    @pytest.mark.vcr()
     def test_validate_label(self) -> None:
         with open(self.label_example_1_uri, encoding="utf-8") as f:
             label_example_1_dict = json.load(f)
@@ -156,20 +161,22 @@ class LabelTest(unittest.TestCase):
             catalog.normalize_and_save(cat_dir, catalog_type=CatalogType.SELF_CONTAINED)
 
             cat_read = Catalog.from_file(os.path.join(cat_dir, "catalog.json"))
-            label_item_read = cat_read.get_item("area-2-2-labels", recursive=True)
-            assert label_item_read is not None
+            label_item_read = next(
+                cat_read.get_items("area-2-2-labels", recursive=True)
+            )
             label_item_read.validate()
 
     def test_read_label_item_owns_asset(self) -> None:
         item = next(
             x
-            for x in TestCases.case_2().get_all_items()
+            for x in TestCases.case_2().get_items(recursive=True)
             if LabelExtension.has_extension(x)
         )
         assert len(item.assets) > 0
         for asset_key in item.assets:
             self.assertEqual(item.assets[asset_key].owner, item)
 
+    @pytest.mark.vcr()
     def test_label_description(self) -> None:
         label_item = pystac.Item.from_file(self.label_example_1_uri)
 
@@ -185,6 +192,7 @@ class LabelTest(unittest.TestCase):
         )
         label_item.validate()
 
+    @pytest.mark.vcr()
     def test_label_type(self) -> None:
         label_item = pystac.Item.from_file(self.label_example_1_uri)
 
@@ -203,6 +211,7 @@ class LabelTest(unittest.TestCase):
             classes_obj.name = None
         label_item.validate()
 
+    @pytest.mark.vcr()
     def test_label_properties(self) -> None:
         label_item = pystac.Item.from_file(self.label_example_1_uri)
         label_item2 = pystac.Item.from_file(self.label_example_2_uri)
@@ -219,6 +228,7 @@ class LabelTest(unittest.TestCase):
         self.assertEqual(["prop1", "prop2"], label_item.properties["label:properties"])
         label_item.validate()
 
+    @pytest.mark.vcr()
     def test_label_classes(self) -> None:
         # Get
         label_item = pystac.Item.from_file(self.label_example_1_uri)
@@ -257,6 +267,7 @@ class LabelTest(unittest.TestCase):
         classes: List[str] = ["foo", "bar"]
         LabelClasses.create(classes=classes)
 
+    @pytest.mark.vcr()
     def test_label_tasks(self) -> None:
         label_item = pystac.Item.from_file(self.label_example_1_uri)
 
@@ -270,6 +281,7 @@ class LabelTest(unittest.TestCase):
         self.assertEqual(["classification"], label_item.properties["label:tasks"])
         label_item.validate()
 
+    @pytest.mark.vcr()
     def test_label_methods(self) -> None:
         label_item = pystac.Item.from_file(self.label_example_1_uri)
 
@@ -285,6 +297,7 @@ class LabelTest(unittest.TestCase):
         )
         label_item.validate()
 
+    @pytest.mark.vcr()
     def test_label_overviews(self) -> None:
         # Get
         label_item = pystac.Item.from_file(self.label_example_1_uri)
@@ -571,7 +584,31 @@ class LabelSummariesTest(unittest.TestCase):
     ) -> None:
         self.assertRaisesRegex(
             ExtensionTypeError,
-            r"^Label extension does not apply to type 'object'$",
+            r"^LabelExtension does not apply to type 'object'$",
             LabelExtension.ext,
             object(),
         )
+
+
+@pytest.fixture
+def ext_item() -> pystac.Item:
+    ext_item_uri = get_data_file("label/label-example-1.json")
+    return pystac.Item.from_file(ext_item_uri)
+
+
+def test_older_extension_version(ext_item: pystac.Item) -> None:
+    old = "https://stac-extensions.github.io/label/v1.0.0/schema.json"
+    new = "https://stac-extensions.github.io/label/v1.0.1/schema.json"
+
+    stac_extensions = set(ext_item.stac_extensions)
+    stac_extensions.remove(new)
+    stac_extensions.add(old)
+    item_as_dict = ext_item.to_dict(include_self_link=False, transform_hrefs=False)
+    item_as_dict["stac_extensions"] = list(stac_extensions)
+    item = pystac.Item.from_dict(item_as_dict)
+    assert LabelExtension.has_extension(item)
+    assert old in item.stac_extensions
+
+    migrated_item = pystac.Item.from_dict(item_as_dict, migrate=True)
+    assert LabelExtension.has_extension(migrated_item)
+    assert new in migrated_item.stac_extensions
