@@ -3,8 +3,10 @@ import unittest
 from copy import deepcopy
 from typing import Any, Dict
 
+import pytest
+
 import pystac
-from pystac import ExtensionTypeError
+from pystac import ExtensionTypeError, Item
 from pystac.extensions.projection import ProjectionExtension
 from pystac.utils import get_opt
 from tests.utils import TestCases, assert_to_from_dict
@@ -84,7 +86,7 @@ class ProjectionTest(unittest.TestCase):
         assert_to_from_dict(self, pystac.Item, d)
 
     def test_apply(self) -> None:
-        item = next(iter(TestCases.case_2().get_all_items()))
+        item = next(TestCases.case_2().get_items(recursive=True))
         self.assertFalse(ProjectionExtension.has_extension(item))
 
         ProjectionExtension.add_to(item)
@@ -99,6 +101,7 @@ class ProjectionTest(unittest.TestCase):
             transform=[30.0, 0.0, 224985.0, 0.0, -30.0, 6790215.0, 0.0, 0.0, 1.0],
         )
 
+    @pytest.mark.vcr()
     def test_partial_apply(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -107,10 +110,12 @@ class ProjectionTest(unittest.TestCase):
         self.assertEqual(ProjectionExtension.ext(proj_item).epsg, 1111)
         proj_item.validate()
 
+    @pytest.mark.vcr()
     def test_validate_proj(self) -> None:
         item = pystac.Item.from_file(self.example_uri)
         item.validate()
 
+    @pytest.mark.vcr()
     def test_epsg(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -158,6 +163,7 @@ class ProjectionTest(unittest.TestCase):
         asset_prop = proj_item.assets["visual"]
         self.assertEqual(ProjectionExtension.ext(asset_prop).epsg, 32618)
 
+    @pytest.mark.vcr()
     def test_wkt2(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -193,6 +199,7 @@ class ProjectionTest(unittest.TestCase):
         # Validate
         proj_item.validate()
 
+    @pytest.mark.vcr()
     def test_projjson(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -258,6 +265,7 @@ class ProjectionTest(unittest.TestCase):
         projection.epsg = 4326
         self.assertEqual(projection.crs_string, "EPSG:4326")
 
+    @pytest.mark.vcr()
     def test_geometry(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -298,6 +306,7 @@ class ProjectionTest(unittest.TestCase):
             ProjectionExtension.ext(proj_item).geometry = {"bad": "data"}
             proj_item.validate()
 
+    @pytest.mark.vcr()
     def test_bbox(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -331,6 +340,7 @@ class ProjectionTest(unittest.TestCase):
         # Validate
         proj_item.validate()
 
+    @pytest.mark.vcr()
     def test_centroid(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -372,6 +382,7 @@ class ProjectionTest(unittest.TestCase):
             ProjectionExtension.ext(proj_item).centroid = {"lat": 2.0, "lng": 3.0}
             proj_item.validate()
 
+    @pytest.mark.vcr()
     def test_shape(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -406,6 +417,7 @@ class ProjectionTest(unittest.TestCase):
         # Validate
         proj_item.validate()
 
+    @pytest.mark.vcr()
     def test_transform(self) -> None:
         proj_item = pystac.Item.from_file(self.example_uri)
 
@@ -485,7 +497,7 @@ class ProjectionTest(unittest.TestCase):
     ) -> None:
         self.assertRaisesRegex(
             ExtensionTypeError,
-            r"^Projection extension does not apply to type 'object'$",
+            r"^ProjectionExtension does not apply to type 'object'$",
             ProjectionExtension.ext,
             object(),
         )
@@ -536,3 +548,23 @@ class ProjectionSummariesTest(unittest.TestCase):
 
         ProjectionExtension.remove_from(col)
         self.assertNotIn(ProjectionExtension.get_schema_uri(), col.stac_extensions)
+
+
+def test_older_extension_version(projection_landsat8_item: Item) -> None:
+    old = "https://stac-extensions.github.io/projection/v1.0.0/schema.json"
+    new = "https://stac-extensions.github.io/projection/v1.1.0/schema.json"
+
+    stac_extensions = set(projection_landsat8_item.stac_extensions)
+    stac_extensions.remove(new)
+    stac_extensions.add(old)
+    item_as_dict = projection_landsat8_item.to_dict(
+        include_self_link=False, transform_hrefs=False
+    )
+    item_as_dict["stac_extensions"] = list(stac_extensions)
+    item = Item.from_dict(item_as_dict)
+    assert ProjectionExtension.has_extension(item)
+    assert old in item.stac_extensions
+
+    migrated_item = pystac.Item.from_dict(item_as_dict, migrate=True)
+    assert ProjectionExtension.has_extension(migrated_item)
+    assert new in migrated_item.stac_extensions
