@@ -1,8 +1,11 @@
 import json
 import unittest
 
+import pytest
+
 import pystac
 from pystac import ExtensionTypeError, Item
+from pystac.extensions.item_assets import ItemAssetsExtension
 from pystac.extensions.raster import (
     DataType,
     Histogram,
@@ -13,6 +16,7 @@ from pystac.extensions.raster import (
     Statistics,
 )
 from pystac.utils import get_opt
+from tests.conftest import get_data_file
 from tests.utils import TestCases, assert_to_from_dict
 
 
@@ -23,6 +27,9 @@ class RasterTest(unittest.TestCase):
     SENTINEL2_EXAMPLE_URI = TestCases.get_path(
         "data-files/raster/raster-sentinel2-example.json"
     )
+    LANDSAT_COLLECTION_EXAMPLE_URI = TestCases.get_path(
+        "data-files/raster/landsat-collection-example.json"
+    )
     GDALINFO_EXAMPLE_URI = TestCases.get_path("data-files/raster/gdalinfo.json")
 
     def setUp(self) -> None:
@@ -33,6 +40,7 @@ class RasterTest(unittest.TestCase):
             item_dict = json.load(f)
         assert_to_from_dict(self, Item, item_dict)
 
+    @pytest.mark.vcr()
     def test_validate_raster(self) -> None:
         item = pystac.Item.from_file(self.PLANET_EXAMPLE_URI)
         item2 = pystac.Item.from_file(self.SENTINEL2_EXAMPLE_URI)
@@ -40,6 +48,7 @@ class RasterTest(unittest.TestCase):
         item.validate()
         item2.validate()
 
+    @pytest.mark.vcr()
     def test_asset_bands(self) -> None:
         item = pystac.Item.from_file(self.PLANET_EXAMPLE_URI)
         item2 = pystac.Item.from_file(self.SENTINEL2_EXAMPLE_URI)
@@ -247,7 +256,7 @@ class RasterTest(unittest.TestCase):
     ) -> None:
         self.assertRaisesRegex(
             ExtensionTypeError,
-            r"^Raster extension does not apply to type 'object'$",
+            r"^RasterExtension does not apply to type 'object'$",
             RasterExtension.ext,
             object(),
         )
@@ -270,3 +279,36 @@ class RasterTest(unittest.TestCase):
 
         RasterExtension.remove_from(col)
         self.assertNotIn(RasterExtension.get_schema_uri(), col.stac_extensions)
+
+    def test_collection_item_asset(self) -> None:
+        coll = pystac.Collection.from_file(self.LANDSAT_COLLECTION_EXAMPLE_URI)
+
+        qa = ItemAssetsExtension.ext(coll).item_assets["qa"]
+        ang = ItemAssetsExtension.ext(coll).item_assets["ang"]
+
+        assert RasterExtension.ext(qa).bands is not None
+        assert RasterExtension.ext(ang).bands is None
+
+
+@pytest.fixture
+def ext_item() -> pystac.Item:
+    ext_item_uri = get_data_file("raster/raster-planet-example.json")
+    return pystac.Item.from_file(ext_item_uri)
+
+
+def test_older_extension_version(ext_item: pystac.Item) -> None:
+    old = "https://stac-extensions.github.io/raster/v1.0.0/schema.json"
+    new = "https://stac-extensions.github.io/raster/v1.1.0/schema.json"
+
+    stac_extensions = set(ext_item.stac_extensions)
+    stac_extensions.remove(new)
+    stac_extensions.add(old)
+    item_as_dict = ext_item.to_dict(include_self_link=False, transform_hrefs=False)
+    item_as_dict["stac_extensions"] = list(stac_extensions)
+    item = pystac.Item.from_dict(item_as_dict)
+    assert RasterExtension.has_extension(item)
+    assert old in item.stac_extensions
+
+    migrated_item = pystac.Item.from_dict(item_as_dict, migrate=True)
+    assert RasterExtension.has_extension(migrated_item)
+    assert new in migrated_item.stac_extensions
