@@ -2,6 +2,8 @@ import json
 import unittest
 from datetime import datetime
 
+import pytest
+
 import pystac
 from pystac import ExtensionTypeError
 from pystac.extensions.timestamps import TimestampsExtension
@@ -25,7 +27,7 @@ class TimestampsTest(unittest.TestCase):
         assert_to_from_dict(self, pystac.Item, self.item_dict)
 
     def test_apply(self) -> None:
-        item = next(iter(TestCases.case_2().get_all_items()))
+        item = next(TestCases.case_2().get_items(recursive=True))
         self.assertFalse(TimestampsExtension.has_extension(item))
 
         TimestampsExtension.add_to(item)
@@ -60,10 +62,12 @@ class TimestampsTest(unittest.TestCase):
         for p in ("expires", "unpublished"):
             self.assertNotIn(p, item.properties)
 
+    @pytest.mark.vcr()
     def test_validate_timestamps(self) -> None:
         item = pystac.Item.from_file(self.example_uri)
         item.validate()
 
+    @pytest.mark.vcr()
     def test_expires(self) -> None:
         timestamps_item = pystac.Item.from_file(self.example_uri)
 
@@ -106,6 +110,7 @@ class TimestampsTest(unittest.TestCase):
         # Validate
         timestamps_item.validate()
 
+    @pytest.mark.vcr()
     def test_published(self) -> None:
         timestamps_item = pystac.Item.from_file(self.example_uri)
 
@@ -148,6 +153,7 @@ class TimestampsTest(unittest.TestCase):
         # Validate
         timestamps_item.validate()
 
+    @pytest.mark.vcr()
     def test_unpublished(self) -> None:
         timestamps_item = pystac.Item.from_file(self.example_uri)
 
@@ -230,7 +236,7 @@ class TimestampsTest(unittest.TestCase):
     ) -> None:
         self.assertRaisesRegex(
             ExtensionTypeError,
-            r"^Timestamps extension does not apply to type 'object'$",
+            r"^TimestampsExtension does not apply to type 'object'$",
             TimestampsExtension.ext,
             object(),
         )
