@@ -42,7 +42,7 @@ class VersionExtensionTest(unittest.TestCase):
     ) -> None:
         self.assertRaisesRegex(
             ExtensionTypeError,
-            r"^Version extension does not apply to type 'object'$",
+            r"^VersionExtension does not apply to type 'object'$",
             VersionExtension.ext,
             object(),
         )
@@ -64,6 +64,7 @@ class ItemVersionExtensionTest(unittest.TestCase):
     def test_stac_extensions(self) -> None:
         self.assertTrue(VersionExtension.has_extension(self.item))
 
+    @pytest.mark.vcr()
     def test_add_version(self) -> None:
         VersionExtension.ext(self.item).apply(self.version)
         self.assertEqual(self.version, VersionExtension.ext(self.item).version)
@@ -71,24 +72,28 @@ class ItemVersionExtensionTest(unittest.TestCase):
         self.assertFalse(VersionExtension.ext(self.item).deprecated)
         self.item.validate()
 
+    @pytest.mark.vcr()
     def test_version_in_properties(self) -> None:
         VersionExtension.ext(self.item).apply(self.version, deprecated=True)
         self.assertIn(version.VERSION, self.item.properties)
         self.assertIn(version.DEPRECATED, self.item.properties)
         self.item.validate()
 
+    @pytest.mark.vcr()
     def test_add_not_deprecated_version(self) -> None:
         VersionExtension.ext(self.item).apply(self.version, deprecated=False)
         self.assertIn(version.DEPRECATED, self.item.properties)
         self.assertFalse(VersionExtension.ext(self.item).deprecated)
         self.item.validate()
 
+    @pytest.mark.vcr()
     def test_add_deprecated_version(self) -> None:
         VersionExtension.ext(self.item).apply(self.version, deprecated=True)
         self.assertIn(version.DEPRECATED, self.item.properties)
         self.assertTrue(VersionExtension.ext(self.item).deprecated)
         self.item.validate()
 
+    @pytest.mark.vcr()
     def test_latest(self) -> None:
         year = 2013
         latest = make_item(year)
@@ -101,6 +106,7 @@ class ItemVersionExtensionTest(unittest.TestCase):
         self.assertEqual(expected_href, link.get_href())
         self.item.validate()
 
+    @pytest.mark.vcr()
     def test_predecessor(self) -> None:
         year = 2010
         predecessor = make_item(year)
@@ -113,6 +119,7 @@ class ItemVersionExtensionTest(unittest.TestCase):
         self.assertEqual(expected_href, link.get_href())
         self.item.validate()
 
+    @pytest.mark.vcr()
     def test_successor(self) -> None:
         year = 2012
         successor = make_item(year)
@@ -125,10 +132,12 @@ class ItemVersionExtensionTest(unittest.TestCase):
         self.assertEqual(expected_href, link.get_href())
         self.item.validate()
 
+    @pytest.mark.vcr()
     def test_fail_validate(self) -> None:
         with self.assertRaises(pystac.STACValidationError):
             self.item.validate()
 
+    @pytest.mark.vcr()
     def test_all_links(self) -> None:
         deprecated = True
         latest = make_item(2013)
@@ -143,11 +152,8 @@ class ItemVersionExtensionTest(unittest.TestCase):
         cat = TestCases.case_1()
 
         # Fetch two items from the catalog
-        item1 = cat.get_item("area-1-1-imagery", recursive=True)
-        item2 = cat.get_item("area-2-2-imagery", recursive=True)
-
-        assert item1 is not None
-        assert item2 is not None
+        item1 = next(cat.get_items("area-1-1-imagery", recursive=True))
+        item2 = next(cat.get_items("area-2-2-imagery", recursive=True))
 
         # Enable the version extension on each, and link them
         # as if they are different versions of the same Item
@@ -161,10 +167,8 @@ class ItemVersionExtensionTest(unittest.TestCase):
         cat_copy = cat.full_copy()
 
         # Retrieve the copied version of the items
-        item1_copy = cat_copy.get_item("area-1-1-imagery", recursive=True)
-        assert item1_copy is not None
-        item2_copy = cat_copy.get_item("area-2-2-imagery", recursive=True)
-        assert item2_copy is not None
+        item1_copy = next(cat_copy.get_items("area-1-1-imagery", recursive=True))
+        item2_copy = next(cat_copy.get_items("area-2-2-imagery", recursive=True))
 
         # Check to see if the version links point to the instances of the
         # item objects as they should.
@@ -289,6 +293,7 @@ class CollectionVersionExtensionTest(unittest.TestCase):
     def test_stac_extensions(self) -> None:
         self.assertTrue(VersionExtension.has_extension(self.collection))
 
+    @pytest.mark.vcr()
     def test_add_version(self) -> None:
         VersionExtension.ext(self.collection).apply(self.version)
         self.assertEqual(self.version, VersionExtension.ext(self.collection).version)
@@ -296,24 +301,28 @@ class CollectionVersionExtensionTest(unittest.TestCase):
         self.assertFalse(VersionExtension.ext(self.collection).deprecated)
         self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_version_deprecated(self) -> None:
         VersionExtension.ext(self.collection).apply(self.version, deprecated=True)
         self.assertIn(version.VERSION, self.collection.extra_fields)
         self.assertIn(version.DEPRECATED, self.collection.extra_fields)
         self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_add_not_deprecated_version(self) -> None:
         VersionExtension.ext(self.collection).apply(self.version, deprecated=False)
         self.assertIn(version.DEPRECATED, self.collection.extra_fields)
         self.assertFalse(VersionExtension.ext(self.collection).deprecated)
         self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_add_deprecated_version(self) -> None:
         VersionExtension.ext(self.collection).apply(self.version, deprecated=True)
         self.assertIn(version.DEPRECATED, self.collection.extra_fields)
         self.assertTrue(VersionExtension.ext(self.collection).deprecated)
         self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_latest(self) -> None:
         year = 2013
         latest = make_collection(year)
@@ -326,6 +335,7 @@ class CollectionVersionExtensionTest(unittest.TestCase):
         self.assertEqual(expected_href, link.get_href())
         self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_predecessor(self) -> None:
         year = 2010
         predecessor = make_collection(year)
@@ -340,6 +350,7 @@ class CollectionVersionExtensionTest(unittest.TestCase):
         self.assertEqual(expected_href, link.get_href())
         self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_successor(self) -> None:
         year = 2012
         successor = make_collection(year)
@@ -352,10 +363,12 @@ class CollectionVersionExtensionTest(unittest.TestCase):
         self.assertEqual(expected_href, link.get_href())
         self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_fail_validate(self) -> None:
         with self.assertRaises(pystac.STACValidationError):
             self.collection.validate()
 
+    @pytest.mark.vcr()
     def test_validate_all(self) -> None:
         deprecated = True
         latest = make_collection(2013)
