@@ -2,13 +2,14 @@ from __future__ import annotations
 
 import json
 import os
+import posixpath
 import tempfile
 import unittest
 from collections import defaultdict
 from copy import deepcopy
 from datetime import datetime
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Tuple, Union, cast
+from typing import Any, Dict, Iterator, List, Optional, Tuple, Union, cast
 
 import pytest
 
@@ -24,10 +25,9 @@ from pystac import (
 )
 from pystac.extensions.label import LabelClasses, LabelExtension, LabelType
 from pystac.utils import (
-    JoinType,
     is_absolute_href,
-    join_path_or_url,
     make_absolute_href,
+    make_posix_style,
     make_relative_href,
 )
 from tests.utils import ARBITRARY_BBOX, ARBITRARY_GEOM, MockStacIO, TestCases
@@ -88,7 +88,7 @@ class TestCatalog:
             collections = catalog.get_children()
             assert len(list(collections)) == 2
 
-            items = read_catalog.get_all_items()
+            items = read_catalog.get_items(recursive=True)
 
             assert len(list(items)) == 8
 
@@ -105,6 +105,12 @@ class TestCatalog:
         _ = Catalog.from_dict(param_dict, preserve_dict=False)
         assert param_dict != catalog_dict
 
+    def test_from_file_bad_catalog(self) -> None:
+        with pytest.raises(pystac.errors.STACTypeError) as ctx:
+            _ = Catalog.from_file(TestCases.get_path(TestCases.bad_catalog_case))
+        assert "(id = broken_cat) does not represent a STACObject" in ctx.value.args[0]
+        assert "is Catalog" in ctx.value.args[0]
+
     def test_from_dict_set_root(self) -> None:
         path = TestCases.get_path("data-files/catalogs/test-case-1/catalog.json")
         with open(path) as f:
@@ -113,6 +119,7 @@ class TestCatalog:
         collection = Catalog.from_dict(cat_dict, root=root_cat)
         assert collection.get_root() is root_cat
 
+    @pytest.mark.vcr()
     def test_read_remote(self) -> None:
         catalog_url = (
             "https://raw.githubusercontent.com/stac-extensions/label/main/"
@@ -138,7 +145,7 @@ class TestCatalog:
         )
         subcat.add_item(item)
 
-        items = list(catalog.get_all_items())
+        items = list(catalog.get_items(recursive=True))
         assert len(items) == 1
         assert items[0].properties["key"] == "one"
 
@@ -152,7 +159,7 @@ class TestCatalog:
         )
         subcat.add_item(item)
 
-        items = list(catalog.get_all_items())
+        items = list(catalog.get_items(recursive=True))
         assert len(items) == 1
         assert items[0].properties["key"] == "two"
 
@@ -166,7 +173,7 @@ class TestCatalog:
         )
         subcat.add_item(item)
 
-        items = list(catalog.get_all_items())
+        items = list(catalog.get_items(recursive=True))
         assert len(items) == 1
         assert items[0].properties["key"] == "three"
 
@@ -218,25 +225,170 @@ class TestCatalog:
 
     def test_add_child_throws_if_item(self) -> None:
         cat = TestCases.case_1()
-        item = next(iter(cat.get_all_items()))
+        item = next(cat.get_items(recursive=True))
         with pytest.raises(pystac.STACError):
             cat.add_child(item)  # type:ignore
 
+    def test_add_child_returns_link(self) -> None:
+        parent = Catalog(id="parent", description="test")
+        child = Catalog(id="child", description="test")
+        link = parent.add_child(child)
+        assert isinstance(link, pystac.Link)
+        link.extra_fields["foo"] = "bar"
+        link2 = parent.get_single_link("child")
+        assert link2 is not None
+        assert link2.extra_fields["foo"] == "bar"
+
+    def test_add_children_returns_links(self) -> None:
+        parent = Catalog(id="parent", description="test")
+        child1 = Catalog(id="child", description="test")
+        child2 = Catalog(id="child2", description="test")
+        links = parent.add_children([child1, child2])
+        assert isinstance(links, list)
+        assert len(links) == 2
+        assert isinstance(links[0], pystac.Link)
+        assert isinstance(links[1], pystac.Link)
+        links2 = parent.get_links("child")
+        assert links[0] in links2
+        assert links[1] in links2
+
+    def test_add_child_override_parent(self) -> None:
+        parent1 = Catalog(id="parent1", description="test1")
+        parent2 = Catalog(id="parent2", description="test2")
+        child = Catalog(id="child", description="test3")
+        assert child.get_parent() is None
+
+        parent1.add_child(child)
+        assert child.get_parent() is parent1
+
+        parent2.add_child(child)
+        assert child.get_parent() is parent2
+
+    def test_add_child_set_parent_false(self) -> None:
+        parent1 = Catalog(id="parent1", description="test1")
+        parent2 = Catalog(id="parent2", description="test2")
+        child = Catalog(id="child", description="test3")
+        assert child.get_parent() is None
+
+        parent1.add_child(child, set_parent=False)
+        assert child.get_parent() is not parent1
+
+        parent1.add_child(child)
+        parent2.add_child(child, set_parent=False)
+        assert child.get_parent() is parent1
+
+    def test_add_item_override_parent(self) -> None:
+        parent1 = Catalog(id="parent1", description="test1")
+        parent2 = Catalog(id="parent2", description="test2")
+        child = Item(
+            id="child",
+            geometry=None,
+            bbox=None,
+            datetime=datetime.now(),
+            properties={},
+        )
+        assert child.get_parent() is None
+
+        parent1.add_item(child)
+        assert child.get_parent() is parent1
+
+        parent2.add_item(child)
+        assert child.get_parent() is parent2
+
+    def test_add_item_set_parent_false(self) -> None:
+        parent1 = Catalog(id="parent1", description="test1")
+        parent2 = Catalog(id="parent2", description="test2")
+        child = Item(
+            id="child",
+            geometry=None,
+            bbox=None,
+            datetime=datetime.now(),
+            properties={},
+        )
+        assert child.get_parent() is None
+
+        parent1.add_item(child, set_parent=False)
+        assert child.get_parent() is not parent1
+
+        parent1.add_item(child)
+        parent2.add_item(child, set_parent=False)
+        assert child.get_parent() is parent1
+
     def test_add_item_throws_if_child(self) -> None:
         cat = TestCases.case_1()
         child = next(iter(cat.get_children()))
         with pytest.raises(pystac.STACError):
             cat.add_item(child)  # type:ignore
 
+    def test_add_item_returns_link(self) -> None:
+        parent = Catalog(id="parent", description="test")
+        child = Item(
+            id="child",
+            geometry=None,
+            bbox=None,
+            datetime=datetime.now(),
+            properties={},
+        )
+        link = parent.add_item(child)
+        assert isinstance(link, pystac.Link)
+        link.extra_fields["foo"] = "bar"
+        link2 = parent.get_single_link("item")
+        assert link2 is not None
+        assert link2.extra_fields["foo"] == "bar"
+
+    def test_add_items_returns_links(self) -> None:
+        parent = Catalog(id="parent", description="test")
+        child1 = Item(
+            id="child1",
+            geometry=None,
+            bbox=None,
+            datetime=datetime.now(),
+            properties={},
+        )
+        child2 = Item(
+            id="child2",
+            geometry=None,
+            bbox=None,
+            datetime=datetime.now(),
+            properties={},
+        )
+        links = parent.add_items([child1, child2])
+        assert isinstance(links, list)
+        assert len(links) == 2
+        assert isinstance(links[0], pystac.Link)
+        assert isinstance(links[1], pystac.Link)
+        links2 = parent.get_links("item")
+        assert links[0] in links2
+        assert links[1] in links2
+
     def test_get_child_returns_none_if_not_found(self) -> None:
         cat = TestCases.case_1()
         child = cat.get_child("thisshouldnotbeachildid", recursive=True)
         assert child is None
 
+    def test_get_item_is_deprecated_but_still_works(self) -> None:
+        cat = TestCases.case_1()
+        with pytest.warns(DeprecationWarning):
+            item = cat.get_item("area-2-1-imagery", recursive=True)
+            assert item is not None
+
     def test_get_item_returns_none_if_not_found(self) -> None:
         cat = TestCases.case_1()
-        item = cat.get_item("thisshouldnotbeanitemid", recursive=True)
-        assert item is None
+        with pytest.warns(DeprecationWarning):
+            item = cat.get_item("thisshouldnotbeanitemid", recursive=True)
+            assert item is None
+
+    def test_get_all_items_is_deprecated_but_still_works(self) -> None:
+        cat = TestCases.case_1()
+        with pytest.warns(DeprecationWarning):
+            all_items = cat.get_all_items()
+        items = cat.get_items(recursive=True)
+        assert all(a == i for a, i in zip(all_items, items))
+
+    def test_get_items_returns_empty_generator_if_not_found(self) -> None:
+        cat = TestCases.case_1()
+        items = cat.get_items("thisshouldnotbeanitemid", recursive=True)
+        assert next(items, None) is None
 
     def test_sets_catalog_type(self) -> None:
         cat = TestCases.case_1()
@@ -415,7 +567,7 @@ class TestCatalog:
                 ), f"{expected_child_path} is not a file."
 
             # Check each item
-            for item in catalog.get_all_items():
+            for item in catalog.get_items(recursive=True):
                 relative_path = make_relative_href(
                     item.self_href, catalog.self_href, start_is_dir=False
                 )
@@ -460,7 +612,7 @@ class TestCatalog:
     def test_normalize_hrefs_makes_absolute_href(self) -> None:
         catalog = TestCases.case_1()
         catalog.normalize_hrefs("./relativepath")
-        abspath = os.path.abspath("./relativepath")
+        abspath = make_posix_style(os.path.abspath("./relativepath"))
         self_href = catalog.get_self_href()
         assert self_href is not None
         assert self_href.startswith(abspath)
@@ -468,8 +620,7 @@ class TestCatalog:
     def test_normalize_href_works_with_label_source_links(self) -> None:
         catalog = TestCases.case_1()
         catalog.normalize_hrefs("http://example.com")
-        item = catalog.get_item("area-1-1-labels", recursive=True)
-        assert item is not None
+        item = next(catalog.get_items("area-1-1-labels", recursive=True))
         source = next(iter(LabelExtension.ext(item).get_sources()))
         assert source.get_self_href() == (
             "http://example.com/country-1/area-1-1/area-1-1-imagery/"
@@ -542,7 +693,8 @@ class TestCatalog:
         catalog = TestCases.case_7()
 
         item_counts = {
-            cat.id: len(list(cat.get_all_items())) for cat in catalog.get_children()
+            cat.id: len(list(cat.get_items(recursive=True)))
+            for cat in catalog.get_children()
         }
 
         catalog.generate_subcatalogs("${year}/${day}")
@@ -553,7 +705,7 @@ class TestCatalog:
 
             cat2 = pystac.Catalog.from_file(os.path.join(tmp_dir, "catalog.json"))
             for child in cat2.get_children():
-                actual = len(list(child.get_all_items()))
+                actual = len(list(child.get_items(recursive=True)))
                 expected = item_counts[child.id]
                 assert actual == expected, " for child '{}'".format(child.id)
 
@@ -587,13 +739,13 @@ class TestCatalog:
         _ = catalog.generate_subcatalogs("${year}/${month}")
         catalog.normalize_hrefs("/tmp")
         expected_hrefs = {
-            item.id: item.get_self_href() for item in catalog.get_all_items()
+            item.id: item.get_self_href() for item in catalog.get_items(recursive=True)
         }
 
         result = catalog.generate_subcatalogs("${year}/${month}")
         assert len(result) == 0
         catalog.normalize_hrefs("/tmp")
-        for item in catalog.get_all_items():
+        for item in catalog.get_items(recursive=True):
             assert (
                 item.get_self_href() == expected_hrefs[item.id]
             ), " for item '{}'".format(item.id)
@@ -623,12 +775,10 @@ class TestCatalog:
         catalog.generate_subcatalogs("${property1}/${property2}")
 
         catalog.normalize_hrefs("/tmp")
-        item1 = catalog.get_item("item1", recursive=True)
-        assert item1 is not None
+        item1 = next(catalog.get_items("item1", recursive=True))
         item1_parent = item1.get_parent()
         assert item1_parent is not None
-        item2 = catalog.get_item("item2", recursive=True)
-        assert item2 is not None
+        item2 = next(catalog.get_items("item2", recursive=True))
         item2_parent = item2.get_parent()
         assert item2_parent is not None
         assert item1_parent.get_self_href() == item2_parent.get_self_href()
@@ -681,12 +831,12 @@ class TestCatalog:
         assert len(result) == 6
 
         catalog.normalize_hrefs("/")
-        for item in catalog.get_all_items():
+        for item in catalog.get_items(recursive=True):
             item_parent = item.get_parent()
             assert item_parent is not None
             parent_href = item_parent.self_href
             path_to_parent, _ = os.path.split(parent_href)
-            subcats = [el for el in path_to_parent.split(os.sep) if el]
+            subcats = [el for el in path_to_parent.split("/") if el]
             assert len(subcats) == 2, " for item '{}'".format(item.id)
 
     def test_map_items(self) -> None:
@@ -704,10 +854,10 @@ class TestCatalog:
 
             result_cat = Catalog.from_file(os.path.join(tmp_dir, "cat", "catalog.json"))
 
-            for item in result_cat.get_all_items():
+            for item in result_cat.get_items(recursive=True):
                 assert "ITEM_MAPPER" in item.properties
 
-            for item in catalog.get_all_items():
+            for item in catalog.get_items(recursive=True):
                 assert "ITEM_MAPPER" not in item.properties
 
     def test_map_items_multiple(self) -> None:
@@ -720,7 +870,7 @@ class TestCatalog:
 
         with tempfile.TemporaryDirectory() as tmp_dir:
             catalog = TestCases.case_1()
-            catalog_items = list(catalog.get_all_items())
+            catalog_items = list(catalog.get_items(recursive=True))
 
             new_cat = catalog.map_items(item_mapper)
 
@@ -728,7 +878,7 @@ class TestCatalog:
             new_cat.save(catalog_type=CatalogType.ABSOLUTE_PUBLISHED)
 
             result_cat = Catalog.from_file(os.path.join(tmp_dir, "cat", "catalog.json"))
-            result_items = list(result_cat.get_all_items())
+            result_items = list(result_cat.get_items(recursive=True))
 
             assert len(catalog_items) * 2 == len(result_items)
 
@@ -745,7 +895,7 @@ class TestCatalog:
 
             assert ones == twos
 
-            for item in catalog.get_all_items():
+            for item in catalog.get_items(recursive=True):
                 assert ("ITEM_MAPPER_1" not in item.properties) and (
                     "ITEM_MAPPER_2" not in item.properties
                 )
@@ -809,7 +959,7 @@ class TestCatalog:
         c = c.map_items(create_label_item)
         new_catalog = c
 
-        items = new_catalog.get_all_items()
+        items = new_catalog.get_items(recursive=True)
         assert len(list(items)) == 4
 
     def test_map_assets_single(self) -> None:
@@ -832,7 +982,7 @@ class TestCatalog:
             result_cat = Catalog.from_file(os.path.join(tmp_dir, "cat", "catalog.json"))
 
             found = False
-            for item in result_cat.get_all_items():
+            for item in result_cat.get_items(recursive=True):
                 for key, asset in item.assets.items():
                     if key == changed_asset:
                         found = True
@@ -866,7 +1016,7 @@ class TestCatalog:
 
             found = False
             not_found = False
-            for item in result_cat.get_all_items():
+            for item in result_cat.get_items(recursive=True):
                 for key, asset in item.assets.items():
                     if key.replace("-modified", "") in changed_assets:
                         found = True
@@ -907,7 +1057,7 @@ class TestCatalog:
             found1 = False
             found2 = False
             not_found = False
-            for item in result_cat.get_all_items():
+            for item in result_cat.get_items(recursive=True):
                 for key, asset in item.assets.items():
                     if key.replace("-mod-1", "") in changed_assets:
                         found1 = True
@@ -926,17 +1076,16 @@ class TestCatalog:
     def test_make_all_asset_hrefs_absolute(self) -> None:
         cat = TestCases.case_2()
         cat.make_all_asset_hrefs_absolute()
-        item = cat.get_item("cf73ec1a-d790-4b59-b077-e101738571ed", recursive=True)
-        assert item is not None
-
-        href = item.assets["cf73ec1a-d790-4b59-b077-e101738571ed"].href
+        ID = "cf73ec1a-d790-4b59-b077-e101738571ed"
+        item = next(cat.get_items(ID, recursive=True))
+        href = item.assets[ID].href
         assert is_absolute_href(href)
 
     def test_make_all_asset_hrefs_relative(self) -> None:
         cat = TestCases.case_2()
-        item = cat.get_item("cf73ec1a-d790-4b59-b077-e101738571ed", recursive=True)
-        assert item is not None
-        asset = item.assets["cf73ec1a-d790-4b59-b077-e101738571ed"]
+        ID = "cf73ec1a-d790-4b59-b077-e101738571ed"
+        item = next(cat.get_items(ID, recursive=True))
+        asset = item.assets[ID]
         original_href = asset.href
         cat.make_all_asset_hrefs_absolute()
 
@@ -975,6 +1124,7 @@ class TestCatalog:
             c2.catalog_type = CatalogType.ABSOLUTE_PUBLISHED
             check_all_absolute(c2)
 
+    @pytest.mark.block_network()
     def test_self_contained_catalog_collection_item_links(self) -> None:
         """See issue https://github.com/stac-utils/pystac/issues/657"""
         with tempfile.TemporaryDirectory() as tmp_dir:
@@ -1053,16 +1203,18 @@ class TestCatalog:
             assert read_cat.extra_fields["custom_field"] == "Special content"
 
     @pytest.mark.parametrize("cat", TestCases.all_test_catalogs())
+    @pytest.mark.vcr()
     def test_validate_all(self, cat: Catalog) -> None:
         # If hrefs are not set, it will fail validation.
         if cat.get_self_href() is None:
             cat.normalize_hrefs("/tmp")
         cat.validate_all()
 
+    @pytest.mark.vcr()
+    def test_validate_all_invalid(self) -> None:
         # Make one invalid, write it off, read it in, ensure it throws
         cat = TestCases.case_1()
-        item = cat.get_item("area-1-1-labels", recursive=True)
-        assert item is not None
+        item = next(cat.get_items("area-1-1-labels", recursive=True))
         item.geometry = {"type": "INVALID", "coordinates": "NONE"}
         with tempfile.TemporaryDirectory() as tmp_dir:
             cat.normalize_hrefs(tmp_dir)
@@ -1079,7 +1231,7 @@ class TestCatalog:
         # Modify the datetimes
         year = 2004
         month = 2
-        for item in catalog.get_all_items():
+        for item in catalog.get_items(recursive=True):
             assert item.datetime is not None
             item.datetime = item.datetime.replace(year=year, month=month)
             year += 1
@@ -1112,16 +1264,17 @@ class TestCatalog:
             for root, _, items in read_catalog.walk():
                 parent = root.get_parent()
                 if parent is None:
-                    assert root.get_self_href() == os.path.join(tmp_dir, "catalog.json")
+                    assert root.get_self_href() == make_posix_style(
+                        os.path.join(tmp_dir, "catalog.json")
+                    )
                 else:
                     d = os.path.dirname(parent.self_href)
-                    assert root.get_self_href() == os.path.join(
-                        d, root.id, root.DEFAULT_FILE_NAME
+                    assert root.get_self_href() == make_posix_style(
+                        os.path.join(d, root.id, root.DEFAULT_FILE_NAME)
                     )
                 for item in items:
                     assert item.datetime is not None
-                    end = join_path_or_url(
-                        JoinType.PATH,
+                    end = posixpath.join(
                         "{}-{}".format(item.datetime.year, item.datetime.month),
                         "{}.json".format(item.id),
                     )
@@ -1162,7 +1315,7 @@ class TestCatalog:
 
         # Iterate over the items. This was causing failure in
         # in the later iterations as per issue #88
-        for item in cat.get_all_items():
+        for item in cat.get_items(recursive=True):
             pass
 
         with tempfile.TemporaryDirectory() as tmp_dir:
@@ -1173,7 +1326,7 @@ class TestCatalog:
             # Open the local copy and iterate over it.
             cat2 = Catalog.from_file(os.path.join(new_stac_uri, "catalog.json"))
 
-            for item in cat2.get_all_items():
+            for item in cat2.get_items(recursive=True):
                 # Iterate again over the items. This would fail in #88
                 pass
 
@@ -1194,7 +1347,7 @@ class TestCatalog:
         cat = pystac.Catalog.from_file(
             TestCases.get_path("data-files/invalid/shared-id/catalog.json")
         )
-        items = list(cat.get_all_items())
+        items = list(cat.get_items(recursive=True))
 
         assert len(items) == 1
 
@@ -1206,7 +1359,7 @@ class TestCatalog:
         # cached only by HREF
         assert len(cache.id_keys_to_objects) == 0
 
-    def testfrom_invalid_dict_raises_exception(self) -> None:
+    def test_from_invalid_dict_raises_exception(self) -> None:
         stac_io = pystac.StacIO.default()
         collection_dict = stac_io.read_json(
             TestCases.get_path("data-files/collections/multi-extent.json")
@@ -1405,12 +1558,9 @@ class FullCopyTest(unittest.TestCase):
             self.check_catalog(cat2, "dest")
 
             # Check that the relative asset link was saved correctly in the copy.
-            item = cat2.get_item("cf73ec1a-d790-4b59-b077-e101738571ed", recursive=True)
-            assert item is not None
-
-            href = item.assets[
-                "cf73ec1a-d790-4b59-b077-e101738571ed"
-            ].get_absolute_href()
+            ID = "cf73ec1a-d790-4b59-b077-e101738571ed"
+            item = next(cat2.get_items(ID, recursive=True))
+            href = item.assets[ID].get_absolute_href()
             assert href is not None
             assert os.path.exists(href)
 
@@ -1422,7 +1572,11 @@ class CatalogSubClassTest(unittest.TestCase):
     case_1 = TestCases.get_path("data-files/catalogs/test-case-1/catalog.json")
 
     class BasicCustomCatalog(pystac.Catalog):
-        pass
+        def get_items(self) -> Iterator[Item]:  # type: ignore
+            # This get_items does not have the `recursive` kwarg. This mimics
+            # the current state of pystac-client and is intended to test
+            # backwards compatibility of inherited classes
+            return super().get_items()
 
     def setUp(self) -> None:
         self.stac_io = pystac.StacIO.default()
@@ -1444,6 +1598,18 @@ class CatalogSubClassTest(unittest.TestCase):
 
         self.assertIsInstance(cloned_catalog, self.BasicCustomCatalog)
 
+    def test_get_all_items_works(self) -> None:
+        custom_catalog = self.BasicCustomCatalog.from_file(self.case_1)
+        cloned_catalog = custom_catalog.clone()
+        with pytest.warns(DeprecationWarning):
+            cloned_catalog.get_all_items()
+
+    def test_get_item_works(self) -> None:
+        custom_catalog = self.BasicCustomCatalog.from_file(self.case_1)
+        cloned_catalog = custom_catalog.clone()
+        with pytest.warns(DeprecationWarning):
+            cloned_catalog.get_item("area-1-1-imagery")
+
 
 def test_custom_catalog_from_dict(catalog: Catalog) -> None:
     # https://github.com/stac-utils/pystac/issues/862
@@ -1478,3 +1644,89 @@ def test_fully_resolve(tmp_path: Path, test_case_1_catalog: Catalog) -> None:
     test_case_1_catalog.fully_resolve()
     test_case_1_catalog.save(dest_href=str(tmp_path / "after"))
     assert len(list((tmp_path / "after").glob("**/*.json"))) == 15
+
+
+def test_get_items_with_multiple_ids(test_case_1_catalog: Catalog) -> None:
+    cat = test_case_1_catalog
+    items = cat.get_items("area-2-1-imagery", "area-1-1-labels", recursive=True)
+    assert len(list(items)) == 2
+
+
+@pytest.mark.vcr()
+def test_validate_all_with_max_n(test_case_1_catalog: Catalog) -> None:
+    cat = test_case_1_catalog
+    assert cat.validate_all() == 8
+    assert cat.validate_all(max_items=6) == 6
+    assert cat.validate_all(max_items=1) == 1
+
+
+@pytest.mark.vcr()
+def test_validate_all_with_recusive_off(test_case_1_catalog: Catalog) -> None:
+    cat = test_case_1_catalog
+    assert cat.validate_all() == 8
+    assert cat.validate_all(recursive=False) == 0
+
+
+@pytest.fixture
+def nested_catalog() -> pystac.Catalog:
+    """
+    Structure:
+
+    ├── catalog.json
+    ├── products
+    │   ├── catalog.json
+    │   └── product_a
+    │       └── catalog.json
+    └── variables
+        ├── catalog.json
+        └── variable_a
+            ├── catalog.json
+    """
+    root = pystac.Catalog("root", "root")
+    variables = pystac.Catalog("variables", "variables")
+    products = pystac.Catalog("products", "products")
+
+    root.add_child(variables)
+    root.add_child(products)
+
+    variable_a = pystac.Catalog("variable_a", "variable_a")
+    product_a = pystac.Catalog("product_a", "product_a")
+
+    variables.add_child(variable_a)
+    products.add_child(product_a)
+
+    return root
+
+
+def test_set_parent_false_stores_in_proper_place_on_normalize_and_save(
+    nested_catalog: pystac.Catalog, tmp_path: Path
+) -> None:
+    root = nested_catalog
+    product_a = next(root.get_child("products").get_children())  # type: ignore
+    variable_a = next(root.get_child("variables").get_children())  # type: ignore
+
+    variable_a.add_child(product_a, set_parent=False)
+
+    root.normalize_and_save(
+        root_href=str(tmp_path), catalog_type=pystac.CatalogType.ABSOLUTE_PUBLISHED
+    )
+    assert (tmp_path / "products" / "product_a").exists()
+    assert not (tmp_path / "variables" / "variable_a" / "product_a").exists()
+
+
+def test_set_parent_false_stores_in_proper_place_on_save(
+    nested_catalog: pystac.Catalog, tmp_path: Path
+) -> None:
+    nested_catalog.normalize_and_save(
+        root_href=str(tmp_path), catalog_type=pystac.CatalogType.ABSOLUTE_PUBLISHED
+    )
+    root = pystac.Catalog.from_file(str(tmp_path / "catalog.json"))
+    product_a = next(root.get_child("products").get_children())  # type: ignore
+    variable_a = next(root.get_child("variables").get_children())  # type: ignore
+
+    variable_a.add_child(product_a, set_parent=False)
+
+    root.save(pystac.CatalogType.SELF_CONTAINED, dest_href=str(tmp_path))
+
+    assert (tmp_path / "products" / "product_a").exists()
+    assert not (tmp_path / "variables" / "variable_a" / "product_a").exists()
