@@ -6,13 +6,14 @@ import tempfile
 import unittest
 from copy import deepcopy
 from datetime import datetime
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Iterator, Optional
 
 import pytest
 from dateutil import tz
 
 import pystac
 from pystac import (
+    Asset,
     Catalog,
     CatalogType,
     Collection,
@@ -60,11 +61,11 @@ class CollectionTest(unittest.TestCase):
         bbox = extent.bboxes[0]
         self.assertEqual(len(bbox), 4)
         for x in bbox:
-            self.assertTrue(type(x) is float)
+            self.assertTrue(isinstance(x, float))
 
     def test_read_eo_items_are_heritable(self) -> None:
         cat = TestCases.case_5()
-        item = next(iter(cat.get_all_items()))
+        item = next(cat.get_items(recursive=True))
 
         self.assertTrue(EOExtension.has_extension(item))
 
@@ -224,6 +225,7 @@ class CollectionTest(unittest.TestCase):
         # cached only by HREF
         self.assertEqual(len(cache.id_keys_to_objects), 0)
 
+    @pytest.mark.block_network
     def test_assets(self) -> None:
         path = TestCases.get_path("data-files/collections/with-assets.json")
         with open(path) as f:
@@ -246,7 +248,11 @@ class CollectionTest(unittest.TestCase):
         self.assertCountEqual(multi_filter.keys(), ["thumbnail"])
 
         no_filter = collection.get_assets()
+        self.assertIsNot(no_filter, collection.assets)
         self.assertCountEqual(no_filter.keys(), ["thumbnail"])
+        no_filter["thumbnail"].description = "foo"
+        assert collection.assets["thumbnail"].description != "foo"
+
         no_assets = collection.get_assets(media_type=pystac.MediaType.HDF)
         self.assertEqual(no_assets, {})
 
@@ -374,6 +380,7 @@ class ExtentTest(unittest.TestCase):
 
         _ = TemporalExtent([[start_datetime, end_datetime]])
 
+    @pytest.mark.block_network()
     def test_spatial_allows_single_bbox(self) -> None:
         temporal_extent = TemporalExtent(intervals=[[TEST_DATETIME, None]])
 
@@ -492,7 +499,11 @@ class CollectionSubClassTest(unittest.TestCase):
     MULTI_EXTENT = TestCases.get_path("data-files/collections/multi-extent.json")
 
     class BasicCustomCollection(pystac.Collection):
-        pass
+        def get_items(self) -> Iterator[Item]:  # type: ignore
+            # This get_items does not have the `recursive` kwarg. This mimics
+            # the current state of pystac-client and is intended to test
+            # backwards compatibility of inherited classes
+            return super().get_items()
 
     def setUp(self) -> None:
         self.stac_io = pystac.StacIO.default()
@@ -514,6 +525,33 @@ class CollectionSubClassTest(unittest.TestCase):
 
         self.assertIsInstance(cloned_collection, self.BasicCustomCollection)
 
+    def test_collection_get_item_works(self) -> None:
+        path = TestCases.get_path(
+            "data-files/catalogs/test-case-1/country-1/area-1-1/collection.json"
+        )
+        custom_collection = self.BasicCustomCollection.from_file(path)
+        collection = custom_collection.clone()
+        with pytest.warns(DeprecationWarning):
+            collection.get_item("area-1-1-imagery")
+
+
+class CollectionPartialSubClassTest(unittest.TestCase):
+    class BasicCustomCollection(pystac.Collection):
+        def get_items(  # type: ignore
+            self, *, recursive: bool = False
+        ) -> Iterator[Item]:
+            # This get_items does not allow ids as args.
+            return super().get_items(recursive=recursive)
+
+    def test_collection_get_item_raises_type_error(self) -> None:
+        path = TestCases.get_path(
+            "data-files/catalogs/test-case-1/country-1/area-1-1/collection.json"
+        )
+        custom_collection = self.BasicCustomCollection.from_file(path)
+        collection = custom_collection.clone()
+        with pytest.raises(TypeError, match="takes 1 positional argument"):
+            collection.get_item("area-1-1-imagery")
+
 
 def test_custom_collection_from_dict(collection: Collection) -> None:
     # https://github.com/stac-utils/pystac/issues/862
@@ -541,3 +579,84 @@ def test_remove_hierarchical_links(
     for link in collection.links:
         assert not link.is_hierarchical()
     assert bool(collection.get_single_link("canonical")) == add_canonical
+
+
+@pytest.mark.parametrize("child", ["country-1", "country-2"])
+def test_get_child_checks_links_where_hrefs_contains_id_first(
+    test_case_1_catalog: Catalog, child: str
+) -> None:
+    cat1 = test_case_1_catalog
+    country = cat1.get_child(child)
+    assert country is not None
+    child_links = [link for link in cat1.links if link.rel == pystac.RelType.CHILD]
+    for link in child_links:
+        if country.id not in link.href:
+            assert not link.is_resolved()
+
+
+def test_get_child_sort_links_by_id_is_configurable(
+    test_case_1_catalog: Catalog,
+) -> None:
+    cat1 = test_case_1_catalog
+    country = cat1.get_child("country-2", sort_links_by_id=False)
+    assert country is not None
+    child_links = [link for link in cat1.links if link.rel == pystac.RelType.CHILD]
+    for link in child_links:
+        assert link.is_resolved()
+
+
+def test_get_item_returns_none_if_not_found(
+    test_case_8_collection: Collection,
+) -> None:
+    col8 = test_case_8_collection
+    item = col8.get_item("notarealitem")
+    assert item is None
+
+
+def test_get_item_is_not_recursive_by_default(
+    test_case_8_collection: Collection,
+) -> None:
+    col8 = test_case_8_collection
+    item = col8.get_item("20170831_162740_ssc1d1")
+    assert item is None
+
+    item = col8.get_item("20170831_162740_ssc1d1", recursive=True)
+    assert item is not None
+
+
+def test_delete_asset(tmp_asset: Asset, collection: Collection) -> None:
+    asset = tmp_asset
+    href = asset.get_absolute_href()
+    item = asset.owner
+    name = "foo"
+
+    assert href is not None
+    assert item is not None
+
+    collection.add_asset(name, asset)
+
+    # steal the href from the owner and use it as the collection's
+    collection.set_self_href(item.get_self_href())
+
+    collection.delete_asset(name)
+    assert name not in collection.assets
+    assert not os.path.exists(href)
+
+
+def test_delete_asset_relative_no_self_link_fails(
+    tmp_asset: Asset, collection: Collection
+) -> None:
+    asset = tmp_asset
+    href = asset.get_absolute_href()
+    name = "foo"
+
+    assert href is not None
+
+    collection.add_asset(name, asset)
+
+    with pytest.raises(ValueError, match="Cannot delete file") as e:
+        collection.delete_asset(name)
+
+    assert asset.href in str(e.value)
+    assert name in collection.assets
+    assert os.path.exists(href)
