@@ -5,6 +5,7 @@ import os
 import tempfile
 import unittest
 from copy import deepcopy
+from pathlib import Path
 from typing import Any, Dict, Optional
 
 import dateutil.relativedelta
@@ -12,8 +13,14 @@ import pytest
 
 import pystac
 import pystac.serialization.common_properties
-from pystac import Asset, Catalog, Item
-from pystac.utils import datetime_to_str, get_opt, is_absolute_href, str_to_datetime
+from pystac import Asset, Catalog, Collection, Item, Link
+from pystac.utils import (
+    datetime_to_str,
+    get_opt,
+    is_absolute_href,
+    make_posix_style,
+    str_to_datetime,
+)
 from pystac.validation import validate_dict
 from tests.utils import TestCases, assert_to_from_dict
 
@@ -58,7 +65,7 @@ class ItemTest(unittest.TestCase):
 
     def test_set_self_href_does_not_break_asset_hrefs(self) -> None:
         cat = TestCases.case_2()
-        for item in cat.get_all_items():
+        for item in cat.get_items(recursive=True):
             for asset in item.assets.values():
                 if is_absolute_href(asset.href):
                     asset.href = f"./{os.path.basename(asset.href)}"
@@ -68,7 +75,7 @@ class ItemTest(unittest.TestCase):
 
     def test_set_self_href_none_ignores_relative_asset_hrefs(self) -> None:
         cat = TestCases.case_2()
-        for item in cat.get_all_items():
+        for item in cat.get_items(recursive=True):
             for asset in item.assets.values():
                 if is_absolute_href(asset.href):
                     asset.href = f"./{os.path.basename(asset.href)}"
@@ -83,8 +90,8 @@ class ItemTest(unittest.TestCase):
         item.set_self_href(item_path)
         rel_asset = Asset("./data.geojson")
         rel_asset.set_owner(item)
-        expected_href = os.path.abspath(
-            os.path.join(os.path.dirname(item_path), "./data.geojson")
+        expected_href = make_posix_style(
+            os.path.abspath(os.path.join(os.path.dirname(item_path), "./data.geojson"))
         )
         actual_href = rel_asset.get_absolute_href()
         self.assertEqual(expected_href, actual_href)
@@ -121,7 +128,7 @@ class ItemTest(unittest.TestCase):
     def test_clearing_collection(self) -> None:
         collection = TestCases.case_4().get_child("acc")
         assert isinstance(collection, pystac.Collection)
-        item = next(iter(collection.get_all_items()))
+        item = next(collection.get_items(recursive=True))
         self.assertEqual(item.collection_id, collection.id)
         item.set_collection(None)
         self.assertIsNone(item.collection_id)
@@ -139,6 +146,7 @@ class ItemTest(unittest.TestCase):
 
         self.assertEqual("2016-05-03T13:22:30.040000Z", formatted_time)
 
+    @pytest.mark.vcr()
     def test_null_datetime(self) -> None:
         item = pystac.Item.from_file(
             TestCases.get_path("data-files/item/sample-item.json")
@@ -179,12 +187,15 @@ class ItemTest(unittest.TestCase):
             media_type=pystac.MediaType.PNG, role="thumbnail"
         )
         self.assertCountEqual(multi_filter.keys(), ["thumbnail"])
+        multi_filter["thumbnail"].description = "foo"
+        assert item.assets["thumbnail"].description != "foo"
 
         no_filter = item.get_assets()
         self.assertCountEqual(no_filter.keys(), ["analytic", "thumbnail"])
         no_assets = item.get_assets(media_type=pystac.MediaType.HDF)
         self.assertEqual(no_assets, {})
 
+    @pytest.mark.vcr()
     def test_null_datetime_constructor(self) -> None:
         item = pystac.Item.from_file(
             TestCases.get_path("data-files/item/sample-item.json")
@@ -245,11 +256,12 @@ class ItemTest(unittest.TestCase):
         )
 
     def test_read_eo_item_owns_asset(self) -> None:
-        item = next(iter(TestCases.case_1().get_all_items()))
+        item = next(TestCases.case_1().get_items(recursive=True))
         assert len(item.assets) > 0
         for asset_key in item.assets:
             self.assertEqual(item.assets[asset_key].owner, item)
 
+    @pytest.mark.vcr()
     def test_null_geometry(self) -> None:
         m = TestCases.get_path(
             "data-files/examples/1.0.0-beta.2/item-spec/examples/null-geom-item.json"
@@ -281,7 +293,7 @@ class ItemTest(unittest.TestCase):
 
     def test_clone_preserves_assets(self) -> None:
         cat = TestCases.case_2()
-        original_item = next(iter(cat.get_all_items()))
+        original_item = next(cat.get_items(recursive=True))
         assert len(original_item.assets) > 0
         assert all(
             asset.owner is original_item for asset in original_item.assets.values()
@@ -299,7 +311,7 @@ class ItemTest(unittest.TestCase):
 
     def test_make_asset_href_relative_is_noop_on_relative_hrefs(self) -> None:
         cat = TestCases.case_2()
-        item = next(iter(cat.get_all_items()))
+        item = next(cat.get_items(recursive=True))
         asset = list(item.assets.values())[0]
         assert not is_absolute_href(asset.href)
         original_href = asset.get_absolute_href()
@@ -315,12 +327,7 @@ class ItemTest(unittest.TestCase):
         with self.assertRaises(pystac.STACTypeError):
             _ = pystac.Item.from_dict(catalog_dict)
 
-    def test_geo_interface(self) -> None:
-        item = pystac.Item.from_file(
-            TestCases.get_path("data-files/item/sample-item.json")
-        )
-        self.assertEqual(item.geometry, item.__geo_interface__)
-
+    @pytest.mark.vcr()
     def test_relative_extension_path(self) -> None:
         item = pystac.Item.from_file(
             TestCases.get_path(
@@ -461,8 +468,165 @@ def test_item_from_dict_with_missing_type_raises_useful_error() -> None:
 def test_remove_hierarchical_links(
     test_case_1_catalog: Catalog, add_canonical: bool
 ) -> None:
-    item = list(test_case_1_catalog.get_all_items())[0]
+    item = next(test_case_1_catalog.get_items(recursive=True))
     item.remove_hierarchical_links(add_canonical=add_canonical)
     for link in item.links:
         assert not link.is_hierarchical()
     assert bool(item.get_single_link("canonical")) == add_canonical
+
+
+def test_geo_interface() -> None:
+    item = pystac.Item.from_file(TestCases.get_path("data-files/item/sample-item.json"))
+    assert (
+        item.to_dict(include_self_link=False, transform_hrefs=False)
+        == item.__geo_interface__
+    )
+
+
+def test_duplicate_self_links(tmp_path: Path, sample_item: pystac.Item) -> None:
+    # https://github.com/stac-utils/pystac/issues/1102
+    assert len(sample_item.get_links(rel="self")) == 1
+    path = tmp_path / "item.json"
+    sample_item.save_object(include_self_link=True, dest_href=str(path))
+    sample_item = Item.from_file(str(path))
+    assert len(sample_item.get_links(rel="self")) == 1
+
+
+def test_get_derived_from_when_none_exists(test_case_1_catalog: Catalog) -> None:
+    item = next(test_case_1_catalog.get_items(recursive=True))
+    assert item.get_derived_from() == []
+    for link in item.links:
+        assert link.rel != pystac.RelType.DERIVED_FROM
+    assert item.get_single_link(pystac.RelType.DERIVED_FROM) is None
+
+
+def test_add_derived_from(test_case_1_catalog: Catalog) -> None:
+    items = list(test_case_1_catalog.get_items(recursive=True))
+    item_0 = items[0]
+    item_1 = items[1]
+    item_2 = items[2]
+    item_0.add_derived_from(item_1, item_2.self_href)
+    derived_from = item_0.get_derived_from()
+    assert len(derived_from) == 2
+    assert derived_from[0].id == item_1.id
+    assert derived_from[1].id == item_2.id
+    filtered = [
+        link for link in item_0.links if link.rel == pystac.RelType.DERIVED_FROM
+    ]
+    assert len(filtered) == 2
+    assert filtered[0].to_dict(transform_href=False)["href"] == item_1.self_href
+    assert filtered[1].to_dict(transform_href=False)["href"] == item_2.self_href
+
+
+def test_get_unresolvable_derived_from(test_case_1_catalog: Catalog) -> None:
+    item = next(test_case_1_catalog.get_items(recursive=True))
+    item.add_derived_from("foo")
+    with pytest.raises(
+        pystac.STACError, match="Link failed to resolve. Use get_links instead"
+    ):
+        item.get_derived_from()
+
+    links = item.get_links(pystac.RelType.DERIVED_FROM)
+    assert len(links) == 1
+
+
+def test_remove_unresolvable_derived_from(test_case_1_catalog: Catalog) -> None:
+    item = next(test_case_1_catalog.get_items(recursive=True))
+    item.add_derived_from("foo")
+    with pytest.raises(
+        pystac.STACError, match="Link failed to resolve. Use remove_links instead"
+    ):
+        item.remove_derived_from("foo")
+
+    item.remove_links(pystac.RelType.DERIVED_FROM)
+    assert item.get_derived_from() == []
+
+
+def test_remove_derived_from(test_case_1_catalog: Catalog) -> None:
+    items = list(test_case_1_catalog.get_items(recursive=True))
+    item_0 = items[0]
+    item_1 = items[1]
+    item_0.add_derived_from(item_1)
+    item_0.remove_derived_from(item_1.id)
+    assert item_0.get_derived_from() == []
+    for link in item_0.links:
+        assert link.rel != pystac.RelType.DERIVED_FROM
+    assert item_0.get_single_link(pystac.RelType.DERIVED_FROM) is None
+
+
+def test_delete_asset(tmp_asset: Asset) -> None:
+    asset = tmp_asset
+    href = asset.get_absolute_href()
+    item = asset.owner
+
+    assert href is not None
+    assert item is not None
+
+    name = next(k for k in item.assets.keys() if item.assets[k] == asset)
+    item.delete_asset(name)
+
+    assert name not in item.assets
+    assert not os.path.exists(href)
+
+
+def test_delete_asset_relative_no_self_link_fails(tmp_asset: pystac.Asset) -> None:
+    asset = tmp_asset
+    href = asset.get_absolute_href()
+    item = asset.owner
+
+    assert href is not None
+    assert item is not None
+
+    item.set_self_href(None)
+
+    name = next(k for k in item.assets.keys() if item.assets[k] == asset)
+    with pytest.raises(ValueError, match="Cannot delete file") as e:
+        item.delete_asset(name)
+
+    assert asset.href in str(e.value)
+    assert name in item.assets
+    assert os.path.exists(href)
+
+
+def test_resolve_collection_with_root(
+    tmp_path: Path, item: Item, collection: Collection
+) -> None:
+    # Motivated by https://github.com/stac-utils/pystac-client/issues/548
+    catalog = Catalog("root", "the description")
+    item.set_root(catalog)
+
+    collection_path = str(tmp_path / "collection.json")
+    collection.save_object(
+        include_self_link=False,
+        dest_href=collection_path,
+    )
+    item.add_link(Link(rel="collection", target=collection_path))
+
+    read_collection = item.get_collection()
+    assert read_collection
+    root = read_collection.get_root()
+    assert root
+    assert root.id == "root"
+
+
+@pytest.mark.vcr()
+def test_non_hierarchical_relative_link() -> None:
+    root = pystac.Catalog("root", "root")
+    a = pystac.Catalog("a", "a")
+    b = pystac.Catalog("b", "b")
+
+    root.add_child(a)
+    root.add_child(b)
+    a.add_link(pystac.Link("related", b))
+    b.add_link(
+        pystac.Link("item", TestCases.get_path("data-files/item/sample-item.json"))
+    )
+
+    root.catalog_type = pystac.catalog.CatalogType.SELF_CONTAINED
+    root.normalize_hrefs("test_output")
+    related_href = [link for link in a.links if link.rel == "related"][0].get_href()
+
+    assert related_href is not None and not is_absolute_href(related_href)
+    assert a.target_in_hierarchy(b)
+    assert root.target_in_hierarchy(next(b.get_items()))
+    assert root.target_in_hierarchy(root)
